<?php
/**
 * JM_Web_Development\VideoPlace\Post_Thumbnails\Component class
 *
 * @package videoplace
 */

namespace JM_Web_Development\VideoPlace\Media_Grabber;

use JM_Web_Development\VideoPlace\Component_Interface;
use JM_Web_Development\VideoPlace\Templating_Component_Interface;
use function get_theme_file_path;
use function JM_Web_Development\VideoPlace\videoplace;

/**
 * Class for managing post thumbnail support.
 *
 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
 */
class Component implements Component_Interface, Templating_Component_Interface {

	/**
	 * Gets the unique identifier for the theme component.
	 *
	 * @return string Component slug.
	 */
	public function get_slug() : string {
		return 'media_grabber';
	}

	/**
	 * Adds the action and filter hooks to integrate with WordPress.
	 */
	public function initialize() {
		include get_theme_file_path( '/inc/Media_Grabber/class-media-grabber.php' );

		add_action( 'wp_enqueue_scripts', [ $this, 'action_enqueue_fex_video_script' ] );
	}

	/**
	 * Gets template tags to expose as methods on the Template_Tags class instance, accessible through `videoplace()`.
	 *
	 * @return array Associative array of $method_name => $callback_info pairs. Each $callback_info must either be
	 *               a callable or an array with key 'callable'. This approach is used to reserve the possibility of
	 *               adding support for further arguments in the future.
	 */
	public function template_tags() : array {
		return [
			'media_grabber' => [ $this, 'media_grabber' ],
		];
	}

	/**
	 * Loads the runs the media grabber.
	 *
	 * @since 2.0
	 *
	 * @param array $args                The arguments for the media grabber.
	 * @return Hybrid_Media_Grabber      The Hybrid_Media_Grabber object.
	 */
	public function media_grabber( $args = array() ) {
		$media = new Hybrid_Media_Grabber( $args );
		return $media->get_media();
	}

	/**
	 * Loads the script for adding the flex-video class to videos.
	 *
	 * @since 2.0
	 */
	public function action_enqueue_fex_video_script() {
		wp_enqueue_script(
			'videoplace-flex-video',
			get_theme_file_uri( '/assets/js/flex-video.min.js' ),
			[ 'jquery' ],
			videoplace()->get_asset_version( get_theme_file_path( '/assets/js/flex-video.min.js' ) ),
			false
		);
		wp_script_add_data( 'videoplace-flex-video', 'async', true );
		wp_script_add_data( 'videoplace-flex-video', 'precache', true );

	}

}
